ProSHADE: Namespace Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

### - s -

- saveAllCSymmetries() : ProSHADE_internal_symmetry
- saveDetectedCSymmetry() : ProSHADE_internal_symmetry
- saveDSymmetry() : ProSHADE_internal_symmetry
- saveMissingAxisNewOnly() : ProSHADE_internal_symmetry
- searchMissingSymmetrySpace() : ProSHADE_internal_symmetry
- smallestDistanceBetweenAngles() : ProSHADE_internal_symmetry
- sortArrVecHlp() : ProSHADE_internal_symmetry
- sortDSymHlpInv() : ProSHADE_internal_misc
- sortSymHlp() : ProSHADE_internal_misc
- sortSymHlpInv() : ProSHADE_internal_misc
- sortSymInvFoldHlp() : ProSHADE_internal_misc
- SymmetryDetectionTask() : ProSHADE_internal_tasks